# PyFerris Documentation

This directory contains comprehensive documentation for PyFerris core features: **Core Operations**, **Executor**, and **I/O Operations**.

## Documentation Files

- **[index.md](index.md)** - Documentation index and navigation guide
- **[README.md](README.md)** - Main documentation overview  
- **[core.md](core.md)** - Core parallel operations documentation
- **[executor.md](executor.md)** - Task executor and thread pool documentation
- **[io.md](io.md)** - File I/O and parallel processing documentation
- **[examples.md](examples.md)** - Comprehensive examples and use cases
- **[api_reference.md](api_reference.md)** - Complete API reference

## Quick Start

For new users, follow this path:
1. Start with [README.md](README.md) for overview
2. Read [core.md](core.md) for basic parallel operations
3. Explore [examples.md](examples.md) for practical use cases
4. Reference [api_reference.md](api_reference.md) as needed

## Features Documented

### Core Operations (`pyferris.core`)
- `parallel_map()` - Transform data in parallel
- `parallel_filter()` - Filter data in parallel  
- `parallel_reduce()` - Aggregate data in parallel
- `parallel_starmap()` - Apply functions to argument tuples

### Executor (`pyferris.executor`)
- `Executor` class for task management
- Future objects and result handling
- Context managers and resource management
- Performance monitoring and optimization

### I/O Operations (`pyferris.io`)
- **simple_io**: Basic text file operations
- **csv**: High-performance CSV processing
- **json**: JSON and JSON Lines support
- **parallel_io**: Batch file processing

## Documentation Standards

- All code examples are tested and functional
- Performance characteristics are documented
- Error handling patterns are included
- Best practices and optimization tips provided
- Real-world use cases demonstrated

---

*Generated documentation for PyFerris v1.0 - Core, Executor, and I/O features*
